@@ -5,6 +5,7 @@
 #include <kernel/arch/init.h>
 #include <kernel/mm.h>
 #include <kernel/process.h>
+#include <kernel/kmod.h>
 #include <kernel/arch/vid.h>
 #include <kernel/arch/int.h>
 #include <version.h>
@@ -17,6 +18,7 @@ int kernel_main()
 	arch_init();
 	mm_init();
 	process_init();
+	kmod_init();
 
 	vid_puts("\nspeck/" SPECK_ARCH " version " SPECK_VERSION "\n");
 	vid_puts("  Built " SPECK_BUILD_DATE " by " SPECK_BUILD_USER "@"
@@ -38,44 +40,12 @@ void idle_process()
 	while(1);
 }
 
-//-----------------TESTING CODE------------------
-
-#include <kernel/msg.h>
-#include <kernel/irqmsg.h>
-#include <kernel/i386/io.h>
-
 void init_process()
 {
-	pid_t sender;
-	int type;
-	char buf[1];
-	int buflen;
-	int timercount = 5;
-
 	vid_puts("Initial process started\n");
 
-	irqmsg_register(IRQMSG_IRQ(0) | IRQMSG_IRQ(1));
-
-	inb(0x60);
-
-	while(1)
-	{
-		buflen = 1;
-		type = msg_recv(&sender,buf,&buflen);
-		if(type == MSG_TYPE_IPC)
-			continue;
-
-		if(sender == 1)
-			inb(0x60); // keep the kbd happy by emptying buffer
-
-		if(sender == 0)
-			if(timercount-- <= 0)
-				irqmsg_register(IRQMSG_IRQ(1));
-
-		vid_puts("IRQ ");
-		vid_putd(sender);
-		vid_putc('\n');
-	}
+	vid_puts("Loading boot modules...\n");
+	kmod_arch_boot_modules();
 
 	while(1); // DON'T RETURN
 }
